import { commonsTypeIsString } from 'tscommons-es-core/dist';
import { isTCommonsHttpUrlSegments, parseTCommonsHttpUrlSegments } from '../types/tcommons-http-url-segments';
export class CommonsHttpUrl {
    constructor(url) {
        if (isTCommonsHttpUrlSegments(url)) {
            this.internal = url;
        }
        else {
            if (!commonsTypeIsString(url))
                throw new Error('Cannot parse non-string and non-TCommonsHttpUrlSegments url');
            this.internal = parseTCommonsHttpUrlSegments(url);
        }
    }
    get protocol() {
        return this.internal.protocol;
    }
    set protocol(protocol) {
        this.internal.protocol = protocol;
    }
    get hostname() {
        return this.internal.hostname;
    }
    set hostname(hostname) {
        this.internal.hostname = hostname;
    }
    get pathname() {
        return this.internal.pathname;
    }
    set pathname(pathname) {
        this.internal.pathname = pathname;
    }
    get port() {
        return this.internal.port;
    }
    set port(port) {
        this.internal.port = port;
    }
    get username() {
        return this.internal.username;
    }
    set username(username) {
        this.internal.username = username;
    }
    get password() {
        return this.internal.password;
    }
    set password(password) {
        this.internal.password = password;
    }
    get query() {
        return this.internal.query;
    }
    set query(query) {
        this.internal.query = query;
    }
    get anchor() {
        return this.internal.anchor;
    }
    set anchor(anchor) {
        this.internal.anchor = anchor;
    }
    get host() {
        return `${this.hostname}${this.port === undefined ? '' : `:${this.port.toString(10)}`}`;
    }
    get origin() {
        return `${this.protocol}://${this.host}`;
    }
    get href() {
        const parts = [
            `${this.protocol}://`
        ];
        if (this.username && this.password)
            parts.push(`${this.username}:${this.password}@`);
        parts.push(this.host);
        if (!this.pathname.startsWith('/'))
            parts.push('/');
        parts.push(this.pathname);
        if (this.query)
            parts.push(`?${this.query}`);
        if (this.anchor)
            parts.push(`#${this.anchor}`);
        return parts.join('');
    }
}
//# sourceMappingURL=commons-http-url.class.js.map