var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { commonsTypeIsObject } from 'tscommons-es-core';
import { commonsObjectMapObject } from 'tscommons-es-core';
import { ECommonsHttpContentType } from '../enums/ecommons-http-content-type';
import { ECommonsHttpResponseDataType } from '../enums/ecommons-http-response-data-type';
export class CommonsHttpTimeoutError extends Error {
}
export class CommonsHttpClientService {
    static buildHeadersOrParams(data) {
        if (!data)
            return {};
        if (!commonsTypeIsObject(data))
            throw new Error('REST data is not an object');
        return commonsObjectMapObject(data, (value, _key) => {
            if (value === undefined || value === null)
                return '';
            return value.toString(); // eslint-disable-line @typescript-eslint/no-unsafe-return, @typescript-eslint/no-unsafe-member-access, @typescript-eslint/no-unsafe-call
        });
    }
    static appendContentType(contentType, headers) {
        // immutable; deep doesn't matter as it isn't valid for http headers anyway
        const clone = headers === undefined ? {} : Object.assign({}, headers);
        switch (contentType) {
            case ECommonsHttpContentType.FORM_URL:
                clone['Content-Type'] = 'application/x-www-form-urlencoded';
                break;
            case ECommonsHttpContentType.JSON:
                clone['Content-Type'] = 'application/json';
                break;
        }
        return clone;
    }
    constructor(implementation) {
        this.implementation = implementation;
        this.reattemptDebugCallback = (_reattempt, _url, _params, _headers, _options) => {
            // do nothing by default
        };
    }
    setReattemptDebugCallback(callback) {
        this.reattemptDebugCallback = callback;
    }
    head(url, params, // the params can be explicitly undefined (none) as well as optional
    headers, // the headers can be explicitly undefined (none) as well as optional,
    options = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            let maxReattempts = options.maxReattempts || 0;
            let reattempt = 0;
            while (true) {
                try {
                    return yield this.implementation.internalHead(url, CommonsHttpClientService.buildHeadersOrParams(params), CommonsHttpClientService.buildHeadersOrParams(headers), options);
                }
                catch (e) {
                    if (e instanceof CommonsHttpTimeoutError && maxReattempts > 0) {
                        maxReattempts--;
                        reattempt++;
                        this.reattemptDebugCallback(reattempt, url, params, headers, options);
                        continue;
                    }
                    throw e;
                }
            }
        });
    }
    get(url, params, // the params can be explicitly undefined (none) as well as optional
    headers, // the headers can be explicitly undefined (none) as well as optional
    options = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            let maxReattempts = options.maxReattempts || 0;
            let reattempt = 0;
            while (true) {
                try {
                    return yield this.implementation.internalGet(url, CommonsHttpClientService.buildHeadersOrParams(params), CommonsHttpClientService.buildHeadersOrParams(headers), options.responseDataType || ECommonsHttpResponseDataType.STRING, options);
                }
                catch (e) {
                    if (e instanceof CommonsHttpTimeoutError && maxReattempts > 0) {
                        maxReattempts--;
                        reattempt++;
                        this.reattemptDebugCallback(reattempt, url, params, headers, options);
                        continue;
                    }
                    throw e;
                }
            }
        });
    }
    post(url, body, params, // the params can be explicitly undefined (none) as well as optional
    headers, // the headers can be explicitly undefined (none) as well as optional
    options = {}) {
        const builtHeaders = CommonsHttpClientService.appendContentType(options.bodyDataEncoding || ECommonsHttpContentType.FORM_URL, CommonsHttpClientService.buildHeadersOrParams(headers));
        let maxReattempts = options.maxReattempts || 0;
        let reattempt = 0;
        while (true) {
            try {
                return this.implementation.internalPost(url, body, CommonsHttpClientService.buildHeadersOrParams(params), builtHeaders, options.bodyDataEncoding || ECommonsHttpContentType.FORM_URL, options.responseDataType || ECommonsHttpResponseDataType.STRING, options);
            }
            catch (e) {
                if (e instanceof CommonsHttpTimeoutError && maxReattempts > 0) {
                    maxReattempts--;
                    reattempt++;
                    this.reattemptDebugCallback(reattempt, url, params, headers, options);
                    continue;
                }
                throw e;
            }
        }
    }
    put(url, body, params, // the params can be explicitly undefined (none) as well as optional
    headers, // the headers can be explicitly undefined (none) as well as optional
    options = {}) {
        const builtHeaders = CommonsHttpClientService.appendContentType(options.bodyDataEncoding || ECommonsHttpContentType.FORM_URL, CommonsHttpClientService.buildHeadersOrParams(headers));
        let maxReattempts = options.maxReattempts || 0;
        let reattempt = 0;
        while (true) {
            try {
                return this.implementation.internalPut(url, body, CommonsHttpClientService.buildHeadersOrParams(params), builtHeaders, options.bodyDataEncoding || ECommonsHttpContentType.FORM_URL, options.responseDataType || ECommonsHttpResponseDataType.STRING, options);
            }
            catch (e) {
                if (e instanceof CommonsHttpTimeoutError && maxReattempts > 0) {
                    maxReattempts--;
                    reattempt++;
                    this.reattemptDebugCallback(reattempt, url, params, headers, options);
                    continue;
                }
                throw e;
            }
        }
    }
    patch(url, body, params, // the params can be explicitly undefined (none) as well as optional
    headers, // the headers can be explicitly undefined (none) as well as optional
    options = {}) {
        const builtHeaders = CommonsHttpClientService.appendContentType(options.bodyDataEncoding || ECommonsHttpContentType.FORM_URL, CommonsHttpClientService.buildHeadersOrParams(headers));
        let maxReattempts = options.maxReattempts || 0;
        let reattempt = 0;
        while (true) {
            try {
                return this.implementation.internalPatch(url, body, CommonsHttpClientService.buildHeadersOrParams(params), builtHeaders, options.bodyDataEncoding || ECommonsHttpContentType.FORM_URL, options.responseDataType || ECommonsHttpResponseDataType.STRING, options);
            }
            catch (e) {
                if (e instanceof CommonsHttpTimeoutError && maxReattempts > 0) {
                    maxReattempts--;
                    reattempt++;
                    this.reattemptDebugCallback(reattempt, url, params, headers, options);
                    continue;
                }
                throw e;
            }
        }
    }
    delete(url, params, // the params can be explicitly undefined (none) as well as optional
    headers, // the headers can be explicitly undefined (none) as well as optional
    options = {}) {
        let maxReattempts = options.maxReattempts || 0;
        let reattempt = 0;
        while (true) {
            try {
                return this.implementation.internalDelete(url, CommonsHttpClientService.buildHeadersOrParams(params), CommonsHttpClientService.buildHeadersOrParams(headers), options.responseDataType || ECommonsHttpResponseDataType.STRING, options);
            }
            catch (e) {
                if (e instanceof CommonsHttpTimeoutError && maxReattempts > 0) {
                    maxReattempts--;
                    reattempt++;
                    this.reattemptDebugCallback(reattempt, url, params, headers, options);
                    continue;
                }
                throw e;
            }
        }
    }
}
//# sourceMappingURL=commons-http-client.service.js.map